==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/sonnet/ui/configwidget.h <==
/**
 * configwidget.h
 *
 * Copyright (C)  2004  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_CONFIGWIDGET_H
#define KSPELL_CONFIGWIDGET_H

#include <qwidget.h>
#include <kdelibs_export.h>
#include "loader.h"

namespace KSpell2
{
    class Loader;
    class KSPELL2_EXPORT ConfigWidget : public QWidget
    {
        Q_OBJECT
    public:
        ConfigWidget( Loader::Ptr loader, QWidget *parent );
        ~ConfigWidget();

        bool backgroundCheckingButtonShown() const;

    public Q_SLOTS:
        void save();
        void setBackgroundCheckingButtonShown( bool );
        void slotDefault();
    protected Q_SLOTS:
        void slotChanged();

    private:
        void init( Loader::Ptr loader );
        void setFromGUI();
        void setCorrectLanguage( const QStringList& langs );

    private:
        class Private;
        Private* const d;
    };
}

#endif

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/sonnet/ui/configwidget.h <==
/**
 * configwidget.h
 *
 * Copyright (C)  2004  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_CONFIGWIDGET_H
#define KSPELL_CONFIGWIDGET_H

#include <qwidget.h>
#include <kdelibs_export.h>
#include "loader.h"

namespace KSpell2
{
    class Loader;
    class SONNETUI_EXPORT ConfigWidget : public QWidget
    {
        Q_OBJECT
    public:
        ConfigWidget( Loader::Ptr loader, QWidget *parent );
        ~ConfigWidget();

        bool backgroundCheckingButtonShown() const;

    public Q_SLOTS:
        void save();
        void setBackgroundCheckingButtonShown( bool );
        void slotDefault();
    protected Q_SLOTS:
        void slotChanged();

    private:
        void init( Loader::Ptr loader );
        void setFromGUI();
        void setCorrectLanguage( const QStringList& langs );

    private:
        class Private;
        Private* const d;
    };
}

#endif
